## guest

[rzeczownik]

1. gość (np. w domu, w hotelu)

I have guests coming over tonight.
(Dzisiaj wieczorem przychodzą do mnie goście.)

How many guests have you invited?
(Ilu zaprosiłeś gości?)

Guests are asked to leave their rooms by 11am.
(Goście proszeni są o opuszczenie pokoi przed 11 rano.)

How many guests do you want to invite to your party?
(Ilu gości chcesz zaprosić na swoje przyjęcie?)

[przymiotnik]

1. gościnny (dla użytku gości)

We have a guest house where you can sleep.
(Mamy domek gościnny, w którym możecie spać.)

You can sleep in the guest room.
(Możesz spać w pokoju gościnnym.)

2. gościnny (goszczący gdzieś na chwilę, np. występ)

This group is on guest performance.
(Ta grupa jest na występach gościnnych.)

He has a guest concert in Warsaw.
(On ma gościnny koncert w Warszawie.)

[czasownik]

1. wystąpić gościnnie

He guests on a TV program.
(On występuje gościnnie w programie telewizyjnym.)

Would you like to guest on our radio program?
(Chciałbyś wystąpić gościnnie w naszym programie radiowym?)

## as somebody's guest

[rzeczownik]

1. jako czyjś gość

## Be my guest.

1. Czuj się jak u siebie w domu.
2. Proszę bardzo., Nie krępuj się. (dosł. "Bądź moim gościem." - używane jako pozwolenie)